@@ -8,11 +8,11 @@ from benedict.utils import type_util
 def _unflatten_item(key, value, separator):
     keys = key.split(separator)
     if type_util.is_dict(value):
-        return (keys, unflatten(value, separator=separator), )
-    return (keys, value, )
+        return (keys, unflatten(value, separator=separator))
+    return (keys, value)
 
 
-def unflatten(d, separator='_'):
+def unflatten(d, separator="_"):
     new_dict = clone(d, empty=True)
     keys = list(d.keys())
     for key in keys:
