@@ -4,10 +4,10 @@ __author__ = "Fabio Caccamo"
 __copyright__ = "Copyright (c) 2019-present - Fabio Caccamo"
 __description__ = (
     "python-benedict is a dict subclass with keylist/keypath support, normalized I/O"
-    " operations (base64, csv, ini, json, pickle, plist, query-string, toml, xml, yaml)"
+    " operations (base64, csv, ini, json, pickle, plist, query-string, toml, xls, xml, yaml)"
     " and many utilities... for humans, obviously."
 )
 __email__ = "fabio.caccamo@gmail.com"
 __license__ = "MIT"
 __title__ = "benedict"
-__version__ = "0.25.4"
+__version__ = "0.27.0"
