@@ -9,6 +9,7 @@ from benedict.serializers.pickle import PickleSerializer
 from benedict.serializers.plist import PListSerializer
 from benedict.serializers.query_string import QueryStringSerializer
 from benedict.serializers.toml import TOMLSerializer
+from benedict.serializers.xls import XLSSerializer
 from benedict.serializers.xml import XMLSerializer
 from benedict.serializers.yaml import YAMLSerializer
 
@@ -25,6 +26,7 @@ __all__ = [
     "PListSerializer",
     "QueryStringSerializer",
     "TOMLSerializer",
+    "XLSSerializer",
     "XMLSerializer",
     "YAMLSerializer",
 ]
@@ -37,26 +39,32 @@ _PICKLE_SERIALIZER = PickleSerializer()
 _PLIST_SERIALIZER = PListSerializer()
 _QUERY_STRING_SERIALIZER = QueryStringSerializer()
 _TOML_SERIALIZER = TOMLSerializer()
-_YAML_SERIALIZER = YAMLSerializer()
+_XLS_SERIALIZER = XLSSerializer()
 _XML_SERIALIZER = XMLSerializer()
+_YAML_SERIALIZER = YAMLSerializer()
 
-_SERIALIZERS = {
-    "b64": _BASE64_SERIALIZER,
-    "base64": _BASE64_SERIALIZER,
-    "csv": _CSV_SERIALIZER,
-    "ini": _INI_SERIALIZER,
-    "json": _JSON_SERIALIZER,
-    "pickle": _PICKLE_SERIALIZER,
-    "plist": _PLIST_SERIALIZER,
-    "qs": _QUERY_STRING_SERIALIZER,
-    "querystring": _QUERY_STRING_SERIALIZER,
-    "toml": _TOML_SERIALIZER,
-    "yaml": _YAML_SERIALIZER,
-    "yml": _YAML_SERIALIZER,
-    "xml": _XML_SERIALIZER,
-}
+_SERIALIZERS_LIST = [
+    _BASE64_SERIALIZER,
+    _CSV_SERIALIZER,
+    _INI_SERIALIZER,
+    _JSON_SERIALIZER,
+    _PICKLE_SERIALIZER,
+    _PLIST_SERIALIZER,
+    _QUERY_STRING_SERIALIZER,
+    _TOML_SERIALIZER,
+    _YAML_SERIALIZER,
+    _XLS_SERIALIZER,
+    _XML_SERIALIZER,
+]
 
-_SERIALIZERS_EXTENSIONS = [f".{extension}" for extension in _SERIALIZERS.keys()]
+_SERIALIZERS_BY_EXTENSION = {}
+for serializer in _SERIALIZERS_LIST:
+    for extension in serializer.extensions():
+        _SERIALIZERS_BY_EXTENSION[extension] = serializer
+
+_SERIALIZERS_EXTENSIONS = [
+    f".{extension}" for extension in _SERIALIZERS_BY_EXTENSION.keys()
+]
 
 
 def get_format_by_path(path):
@@ -70,8 +78,5 @@ def get_format_by_path(path):
 def get_serializer_by_format(format):
     format_key = (format or "").lower().strip()
     format_key = re.sub(r"[\s\-\_]*", "", format_key)
-    return _SERIALIZERS.get(format_key)
-
-
-def get_serializers_extensions():
-    return list(_SERIALIZERS_EXTENSIONS)
+    serializer = _SERIALIZERS_BY_EXTENSION.get(format_key, None)
+    return serializer
