@@ -14,7 +14,11 @@ class INISerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(INISerializer, self).__init__()
+        super(INISerializer, self).__init__(
+            extensions=[
+                "ini",
+            ],
+        )
 
     @staticmethod
     def _get_section_option_value(parser, section, option):
