@@ -11,12 +11,16 @@ class TOMLSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(TOMLSerializer, self).__init__()
+        super(TOMLSerializer, self).__init__(
+            extensions=[
+                "toml",
+            ],
+        )
 
     def decode(self, s, **kwargs):
         data = toml.loads(s, **kwargs)
         return data
 
     def encode(self, d, **kwargs):
-        data = toml.dumps(d, **kwargs)
+        data = toml.dumps(dict(d), **kwargs)
         return data
